# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GroupAnalyticsModelResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'group': 'GroupChild',
        'assignment_start_date': 'datetime',
        'assignment_end_date': 'datetime',
        'assignment_created_by': 'UserChild',
        'hierarchy': 'list[HierarchyChild]',
        'name': 'str',
        'version': 'str',
        'created': 'datetime',
        'group_type': 'GroupTypeCodes',
        'is_global': 'bool',
        'is_deprecated': 'bool',
        'last_upload': 'datetime',
        'error_type': 'AnalyticsModelErrorTypeCodes',
        'disable_date': 'datetime',
        'trigger_interval_in_seconds': 'int',
        'indicators': 'list[AnalyticsModelIndicatorChild]',
        'properties': 'list[PropertyChild]',
        'created_by': 'UserChild',
        'corporation': 'CorporationChild',
        'location': 'LocationChild',
        'tags': 'list[TagChild]'
    }

    attribute_map = {
        'id': 'Id',
        'group': 'Group',
        'assignment_start_date': 'AssignmentStartDate',
        'assignment_end_date': 'AssignmentEndDate',
        'assignment_created_by': 'AssignmentCreatedBy',
        'hierarchy': 'Hierarchy',
        'name': 'Name',
        'version': 'Version',
        'created': 'Created',
        'group_type': 'GroupType',
        'is_global': 'IsGlobal',
        'is_deprecated': 'IsDeprecated',
        'last_upload': 'LastUpload',
        'error_type': 'ErrorType',
        'disable_date': 'DisableDate',
        'trigger_interval_in_seconds': 'TriggerIntervalInSeconds',
        'indicators': 'Indicators',
        'properties': 'Properties',
        'created_by': 'CreatedBy',
        'corporation': 'Corporation',
        'location': 'Location',
        'tags': 'Tags'
    }

    def __init__(self, id=None, group=None, assignment_start_date=None, assignment_end_date=None, assignment_created_by=None, hierarchy=None, name=None, version=None, created=None, group_type=None, is_global=None, is_deprecated=None, last_upload=None, error_type=None, disable_date=None, trigger_interval_in_seconds=None, indicators=None, properties=None, created_by=None, corporation=None, location=None, tags=None):  # noqa: E501
        """GroupAnalyticsModelResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._group = None
        self._assignment_start_date = None
        self._assignment_end_date = None
        self._assignment_created_by = None
        self._hierarchy = None
        self._name = None
        self._version = None
        self._created = None
        self._group_type = None
        self._is_global = None
        self._is_deprecated = None
        self._last_upload = None
        self._error_type = None
        self._disable_date = None
        self._trigger_interval_in_seconds = None
        self._indicators = None
        self._properties = None
        self._created_by = None
        self._corporation = None
        self._location = None
        self._tags = None
        self.discriminator = None
        self.id = id
        self.group = group
        self.assignment_start_date = assignment_start_date
        if assignment_end_date is not None:
            self.assignment_end_date = assignment_end_date
        self.assignment_created_by = assignment_created_by
        self.hierarchy = hierarchy
        self.name = name
        self.version = version
        self.created = created
        if group_type is not None:
            self.group_type = group_type
        self.is_global = is_global
        self.is_deprecated = is_deprecated
        if last_upload is not None:
            self.last_upload = last_upload
        if error_type is not None:
            self.error_type = error_type
        if disable_date is not None:
            self.disable_date = disable_date
        self.trigger_interval_in_seconds = trigger_interval_in_seconds
        self.indicators = indicators
        self.properties = properties
        self.created_by = created_by
        if corporation is not None:
            self.corporation = corporation
        if location is not None:
            self.location = location
        self.tags = tags

    @property
    def id(self):
        """Gets the id of this GroupAnalyticsModelResponse.  # noqa: E501


        :return: The id of this GroupAnalyticsModelResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this GroupAnalyticsModelResponse.


        :param id: The id of this GroupAnalyticsModelResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def group(self):
        """Gets the group of this GroupAnalyticsModelResponse.  # noqa: E501


        :return: The group of this GroupAnalyticsModelResponse.  # noqa: E501
        :rtype: GroupChild
        """
        return self._group

    @group.setter
    def group(self, group):
        """Sets the group of this GroupAnalyticsModelResponse.


        :param group: The group of this GroupAnalyticsModelResponse.  # noqa: E501
        :type: GroupChild
        """
        if group is None:
            raise ValueError("Invalid value for `group`, must not be `None`")  # noqa: E501

        self._group = group

    @property
    def assignment_start_date(self):
        """Gets the assignment_start_date of this GroupAnalyticsModelResponse.  # noqa: E501


        :return: The assignment_start_date of this GroupAnalyticsModelResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._assignment_start_date

    @assignment_start_date.setter
    def assignment_start_date(self, assignment_start_date):
        """Sets the assignment_start_date of this GroupAnalyticsModelResponse.


        :param assignment_start_date: The assignment_start_date of this GroupAnalyticsModelResponse.  # noqa: E501
        :type: datetime
        """
        if assignment_start_date is None:
            raise ValueError("Invalid value for `assignment_start_date`, must not be `None`")  # noqa: E501

        self._assignment_start_date = assignment_start_date

    @property
    def assignment_end_date(self):
        """Gets the assignment_end_date of this GroupAnalyticsModelResponse.  # noqa: E501


        :return: The assignment_end_date of this GroupAnalyticsModelResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._assignment_end_date

    @assignment_end_date.setter
    def assignment_end_date(self, assignment_end_date):
        """Sets the assignment_end_date of this GroupAnalyticsModelResponse.


        :param assignment_end_date: The assignment_end_date of this GroupAnalyticsModelResponse.  # noqa: E501
        :type: datetime
        """

        self._assignment_end_date = assignment_end_date

    @property
    def assignment_created_by(self):
        """Gets the assignment_created_by of this GroupAnalyticsModelResponse.  # noqa: E501


        :return: The assignment_created_by of this GroupAnalyticsModelResponse.  # noqa: E501
        :rtype: UserChild
        """
        return self._assignment_created_by

    @assignment_created_by.setter
    def assignment_created_by(self, assignment_created_by):
        """Sets the assignment_created_by of this GroupAnalyticsModelResponse.


        :param assignment_created_by: The assignment_created_by of this GroupAnalyticsModelResponse.  # noqa: E501
        :type: UserChild
        """
        if assignment_created_by is None:
            raise ValueError("Invalid value for `assignment_created_by`, must not be `None`")  # noqa: E501

        self._assignment_created_by = assignment_created_by

    @property
    def hierarchy(self):
        """Gets the hierarchy of this GroupAnalyticsModelResponse.  # noqa: E501


        :return: The hierarchy of this GroupAnalyticsModelResponse.  # noqa: E501
        :rtype: list[HierarchyChild]
        """
        return self._hierarchy

    @hierarchy.setter
    def hierarchy(self, hierarchy):
        """Sets the hierarchy of this GroupAnalyticsModelResponse.


        :param hierarchy: The hierarchy of this GroupAnalyticsModelResponse.  # noqa: E501
        :type: list[HierarchyChild]
        """
        if hierarchy is None:
            raise ValueError("Invalid value for `hierarchy`, must not be `None`")  # noqa: E501

        self._hierarchy = hierarchy

    @property
    def name(self):
        """Gets the name of this GroupAnalyticsModelResponse.  # noqa: E501


        :return: The name of this GroupAnalyticsModelResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GroupAnalyticsModelResponse.


        :param name: The name of this GroupAnalyticsModelResponse.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def version(self):
        """Gets the version of this GroupAnalyticsModelResponse.  # noqa: E501


        :return: The version of this GroupAnalyticsModelResponse.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this GroupAnalyticsModelResponse.


        :param version: The version of this GroupAnalyticsModelResponse.  # noqa: E501
        :type: str
        """
        if version is None:
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501

        self._version = version

    @property
    def created(self):
        """Gets the created of this GroupAnalyticsModelResponse.  # noqa: E501


        :return: The created of this GroupAnalyticsModelResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this GroupAnalyticsModelResponse.


        :param created: The created of this GroupAnalyticsModelResponse.  # noqa: E501
        :type: datetime
        """
        if created is None:
            raise ValueError("Invalid value for `created`, must not be `None`")  # noqa: E501

        self._created = created

    @property
    def group_type(self):
        """Gets the group_type of this GroupAnalyticsModelResponse.  # noqa: E501


        :return: The group_type of this GroupAnalyticsModelResponse.  # noqa: E501
        :rtype: GroupTypeCodes
        """
        return self._group_type

    @group_type.setter
    def group_type(self, group_type):
        """Sets the group_type of this GroupAnalyticsModelResponse.


        :param group_type: The group_type of this GroupAnalyticsModelResponse.  # noqa: E501
        :type: GroupTypeCodes
        """

        self._group_type = group_type

    @property
    def is_global(self):
        """Gets the is_global of this GroupAnalyticsModelResponse.  # noqa: E501


        :return: The is_global of this GroupAnalyticsModelResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_global

    @is_global.setter
    def is_global(self, is_global):
        """Sets the is_global of this GroupAnalyticsModelResponse.


        :param is_global: The is_global of this GroupAnalyticsModelResponse.  # noqa: E501
        :type: bool
        """
        if is_global is None:
            raise ValueError("Invalid value for `is_global`, must not be `None`")  # noqa: E501

        self._is_global = is_global

    @property
    def is_deprecated(self):
        """Gets the is_deprecated of this GroupAnalyticsModelResponse.  # noqa: E501


        :return: The is_deprecated of this GroupAnalyticsModelResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_deprecated

    @is_deprecated.setter
    def is_deprecated(self, is_deprecated):
        """Sets the is_deprecated of this GroupAnalyticsModelResponse.


        :param is_deprecated: The is_deprecated of this GroupAnalyticsModelResponse.  # noqa: E501
        :type: bool
        """
        if is_deprecated is None:
            raise ValueError("Invalid value for `is_deprecated`, must not be `None`")  # noqa: E501

        self._is_deprecated = is_deprecated

    @property
    def last_upload(self):
        """Gets the last_upload of this GroupAnalyticsModelResponse.  # noqa: E501


        :return: The last_upload of this GroupAnalyticsModelResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._last_upload

    @last_upload.setter
    def last_upload(self, last_upload):
        """Sets the last_upload of this GroupAnalyticsModelResponse.


        :param last_upload: The last_upload of this GroupAnalyticsModelResponse.  # noqa: E501
        :type: datetime
        """

        self._last_upload = last_upload

    @property
    def error_type(self):
        """Gets the error_type of this GroupAnalyticsModelResponse.  # noqa: E501


        :return: The error_type of this GroupAnalyticsModelResponse.  # noqa: E501
        :rtype: AnalyticsModelErrorTypeCodes
        """
        return self._error_type

    @error_type.setter
    def error_type(self, error_type):
        """Sets the error_type of this GroupAnalyticsModelResponse.


        :param error_type: The error_type of this GroupAnalyticsModelResponse.  # noqa: E501
        :type: AnalyticsModelErrorTypeCodes
        """

        self._error_type = error_type

    @property
    def disable_date(self):
        """Gets the disable_date of this GroupAnalyticsModelResponse.  # noqa: E501


        :return: The disable_date of this GroupAnalyticsModelResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._disable_date

    @disable_date.setter
    def disable_date(self, disable_date):
        """Sets the disable_date of this GroupAnalyticsModelResponse.


        :param disable_date: The disable_date of this GroupAnalyticsModelResponse.  # noqa: E501
        :type: datetime
        """

        self._disable_date = disable_date

    @property
    def trigger_interval_in_seconds(self):
        """Gets the trigger_interval_in_seconds of this GroupAnalyticsModelResponse.  # noqa: E501


        :return: The trigger_interval_in_seconds of this GroupAnalyticsModelResponse.  # noqa: E501
        :rtype: int
        """
        return self._trigger_interval_in_seconds

    @trigger_interval_in_seconds.setter
    def trigger_interval_in_seconds(self, trigger_interval_in_seconds):
        """Sets the trigger_interval_in_seconds of this GroupAnalyticsModelResponse.


        :param trigger_interval_in_seconds: The trigger_interval_in_seconds of this GroupAnalyticsModelResponse.  # noqa: E501
        :type: int
        """
        if trigger_interval_in_seconds is None:
            raise ValueError("Invalid value for `trigger_interval_in_seconds`, must not be `None`")  # noqa: E501

        self._trigger_interval_in_seconds = trigger_interval_in_seconds

    @property
    def indicators(self):
        """Gets the indicators of this GroupAnalyticsModelResponse.  # noqa: E501


        :return: The indicators of this GroupAnalyticsModelResponse.  # noqa: E501
        :rtype: list[AnalyticsModelIndicatorChild]
        """
        return self._indicators

    @indicators.setter
    def indicators(self, indicators):
        """Sets the indicators of this GroupAnalyticsModelResponse.


        :param indicators: The indicators of this GroupAnalyticsModelResponse.  # noqa: E501
        :type: list[AnalyticsModelIndicatorChild]
        """
        if indicators is None:
            raise ValueError("Invalid value for `indicators`, must not be `None`")  # noqa: E501

        self._indicators = indicators

    @property
    def properties(self):
        """Gets the properties of this GroupAnalyticsModelResponse.  # noqa: E501


        :return: The properties of this GroupAnalyticsModelResponse.  # noqa: E501
        :rtype: list[PropertyChild]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this GroupAnalyticsModelResponse.


        :param properties: The properties of this GroupAnalyticsModelResponse.  # noqa: E501
        :type: list[PropertyChild]
        """
        if properties is None:
            raise ValueError("Invalid value for `properties`, must not be `None`")  # noqa: E501

        self._properties = properties

    @property
    def created_by(self):
        """Gets the created_by of this GroupAnalyticsModelResponse.  # noqa: E501


        :return: The created_by of this GroupAnalyticsModelResponse.  # noqa: E501
        :rtype: UserChild
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this GroupAnalyticsModelResponse.


        :param created_by: The created_by of this GroupAnalyticsModelResponse.  # noqa: E501
        :type: UserChild
        """
        if created_by is None:
            raise ValueError("Invalid value for `created_by`, must not be `None`")  # noqa: E501

        self._created_by = created_by

    @property
    def corporation(self):
        """Gets the corporation of this GroupAnalyticsModelResponse.  # noqa: E501


        :return: The corporation of this GroupAnalyticsModelResponse.  # noqa: E501
        :rtype: CorporationChild
        """
        return self._corporation

    @corporation.setter
    def corporation(self, corporation):
        """Sets the corporation of this GroupAnalyticsModelResponse.


        :param corporation: The corporation of this GroupAnalyticsModelResponse.  # noqa: E501
        :type: CorporationChild
        """

        self._corporation = corporation

    @property
    def location(self):
        """Gets the location of this GroupAnalyticsModelResponse.  # noqa: E501


        :return: The location of this GroupAnalyticsModelResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this GroupAnalyticsModelResponse.


        :param location: The location of this GroupAnalyticsModelResponse.  # noqa: E501
        :type: LocationChild
        """

        self._location = location

    @property
    def tags(self):
        """Gets the tags of this GroupAnalyticsModelResponse.  # noqa: E501


        :return: The tags of this GroupAnalyticsModelResponse.  # noqa: E501
        :rtype: list[TagChild]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this GroupAnalyticsModelResponse.


        :param tags: The tags of this GroupAnalyticsModelResponse.  # noqa: E501
        :type: list[TagChild]
        """
        if tags is None:
            raise ValueError("Invalid value for `tags`, must not be `None`")  # noqa: E501

        self._tags = tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GroupAnalyticsModelResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GroupAnalyticsModelResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InstallNodeStatusChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status_id': 'int',
        'status': 'str',
        'status_date': 'datetime',
        'status_note': 'str',
        'install_user': 'str'
    }

    attribute_map = {
        'status_id': 'StatusId',
        'status': 'Status',
        'status_date': 'StatusDate',
        'status_note': 'StatusNote',
        'install_user': 'InstallUser'
    }

    def __init__(self, status_id=None, status=None, status_date=None, status_note=None, install_user=None):  # noqa: E501
        """InstallNodeStatusChild - a model defined in Swagger"""  # noqa: E501
        self._status_id = None
        self._status = None
        self._status_date = None
        self._status_note = None
        self._install_user = None
        self.discriminator = None
        self.status_id = status_id
        if status is not None:
            self.status = status
        if status_date is not None:
            self.status_date = status_date
        if status_note is not None:
            self.status_note = status_note
        if install_user is not None:
            self.install_user = install_user

    @property
    def status_id(self):
        """Gets the status_id of this InstallNodeStatusChild.  # noqa: E501

        The corresponding StatusId  # noqa: E501

        :return: The status_id of this InstallNodeStatusChild.  # noqa: E501
        :rtype: int
        """
        return self._status_id

    @status_id.setter
    def status_id(self, status_id):
        """Sets the status_id of this InstallNodeStatusChild.

        The corresponding StatusId  # noqa: E501

        :param status_id: The status_id of this InstallNodeStatusChild.  # noqa: E501
        :type: int
        """
        if status_id is None:
            raise ValueError("Invalid value for `status_id`, must not be `None`")  # noqa: E501

        self._status_id = status_id

    @property
    def status(self):
        """Gets the status of this InstallNodeStatusChild.  # noqa: E501

        The textual description of the Status  # noqa: E501

        :return: The status of this InstallNodeStatusChild.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InstallNodeStatusChild.

        The textual description of the Status  # noqa: E501

        :param status: The status of this InstallNodeStatusChild.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def status_date(self):
        """Gets the status_date of this InstallNodeStatusChild.  # noqa: E501

        The DateTime that the current status was set as part of an install activity  # noqa: E501

        :return: The status_date of this InstallNodeStatusChild.  # noqa: E501
        :rtype: datetime
        """
        return self._status_date

    @status_date.setter
    def status_date(self, status_date):
        """Sets the status_date of this InstallNodeStatusChild.

        The DateTime that the current status was set as part of an install activity  # noqa: E501

        :param status_date: The status_date of this InstallNodeStatusChild.  # noqa: E501
        :type: datetime
        """

        self._status_date = status_date

    @property
    def status_note(self):
        """Gets the status_note of this InstallNodeStatusChild.  # noqa: E501

        A brief note about the installation of the node, typically used when   something prevents a node from being installed to keep records  # noqa: E501

        :return: The status_note of this InstallNodeStatusChild.  # noqa: E501
        :rtype: str
        """
        return self._status_note

    @status_note.setter
    def status_note(self, status_note):
        """Sets the status_note of this InstallNodeStatusChild.

        A brief note about the installation of the node, typically used when   something prevents a node from being installed to keep records  # noqa: E501

        :param status_note: The status_note of this InstallNodeStatusChild.  # noqa: E501
        :type: str
        """

        self._status_note = status_note

    @property
    def install_user(self):
        """Gets the install_user of this InstallNodeStatusChild.  # noqa: E501

        The user that set the current install status  # noqa: E501

        :return: The install_user of this InstallNodeStatusChild.  # noqa: E501
        :rtype: str
        """
        return self._install_user

    @install_user.setter
    def install_user(self, install_user):
        """Sets the install_user of this InstallNodeStatusChild.

        The user that set the current install status  # noqa: E501

        :param install_user: The install_user of this InstallNodeStatusChild.  # noqa: E501
        :type: str
        """

        self._install_user = install_user

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InstallNodeStatusChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InstallNodeStatusChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class NodeStatusChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'outstanding': 'int',
        'deployed': 'int',
        'lock_out_tag_out': 'int',
        'spare_devices': 'int',
        'special_access_required': 'int'
    }

    attribute_map = {
        'outstanding': 'Outstanding',
        'deployed': 'Deployed',
        'lock_out_tag_out': 'LockOutTagOut',
        'spare_devices': 'SpareDevices',
        'special_access_required': 'SpecialAccessRequired'
    }

    def __init__(self, outstanding=None, deployed=None, lock_out_tag_out=None, spare_devices=None, special_access_required=None):  # noqa: E501
        """NodeStatusChild - a model defined in Swagger"""  # noqa: E501
        self._outstanding = None
        self._deployed = None
        self._lock_out_tag_out = None
        self._spare_devices = None
        self._special_access_required = None
        self.discriminator = None
        self.outstanding = outstanding
        self.deployed = deployed
        self.lock_out_tag_out = lock_out_tag_out
        self.spare_devices = spare_devices
        self.special_access_required = special_access_required

    @property
    def outstanding(self):
        """Gets the outstanding of this NodeStatusChild.  # noqa: E501


        :return: The outstanding of this NodeStatusChild.  # noqa: E501
        :rtype: int
        """
        return self._outstanding

    @outstanding.setter
    def outstanding(self, outstanding):
        """Sets the outstanding of this NodeStatusChild.


        :param outstanding: The outstanding of this NodeStatusChild.  # noqa: E501
        :type: int
        """
        if outstanding is None:
            raise ValueError("Invalid value for `outstanding`, must not be `None`")  # noqa: E501

        self._outstanding = outstanding

    @property
    def deployed(self):
        """Gets the deployed of this NodeStatusChild.  # noqa: E501


        :return: The deployed of this NodeStatusChild.  # noqa: E501
        :rtype: int
        """
        return self._deployed

    @deployed.setter
    def deployed(self, deployed):
        """Sets the deployed of this NodeStatusChild.


        :param deployed: The deployed of this NodeStatusChild.  # noqa: E501
        :type: int
        """
        if deployed is None:
            raise ValueError("Invalid value for `deployed`, must not be `None`")  # noqa: E501

        self._deployed = deployed

    @property
    def lock_out_tag_out(self):
        """Gets the lock_out_tag_out of this NodeStatusChild.  # noqa: E501


        :return: The lock_out_tag_out of this NodeStatusChild.  # noqa: E501
        :rtype: int
        """
        return self._lock_out_tag_out

    @lock_out_tag_out.setter
    def lock_out_tag_out(self, lock_out_tag_out):
        """Sets the lock_out_tag_out of this NodeStatusChild.


        :param lock_out_tag_out: The lock_out_tag_out of this NodeStatusChild.  # noqa: E501
        :type: int
        """
        if lock_out_tag_out is None:
            raise ValueError("Invalid value for `lock_out_tag_out`, must not be `None`")  # noqa: E501

        self._lock_out_tag_out = lock_out_tag_out

    @property
    def spare_devices(self):
        """Gets the spare_devices of this NodeStatusChild.  # noqa: E501


        :return: The spare_devices of this NodeStatusChild.  # noqa: E501
        :rtype: int
        """
        return self._spare_devices

    @spare_devices.setter
    def spare_devices(self, spare_devices):
        """Sets the spare_devices of this NodeStatusChild.


        :param spare_devices: The spare_devices of this NodeStatusChild.  # noqa: E501
        :type: int
        """
        if spare_devices is None:
            raise ValueError("Invalid value for `spare_devices`, must not be `None`")  # noqa: E501

        self._spare_devices = spare_devices

    @property
    def special_access_required(self):
        """Gets the special_access_required of this NodeStatusChild.  # noqa: E501


        :return: The special_access_required of this NodeStatusChild.  # noqa: E501
        :rtype: int
        """
        return self._special_access_required

    @special_access_required.setter
    def special_access_required(self, special_access_required):
        """Sets the special_access_required of this NodeStatusChild.


        :param special_access_required: The special_access_required of this NodeStatusChild.  # noqa: E501
        :type: int
        """
        if special_access_required is None:
            raise ValueError("Invalid value for `special_access_required`, must not be `None`")  # noqa: E501

        self._special_access_required = special_access_required

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NodeStatusChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NodeStatusChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.assets_api import AssetsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestAssetsApi(unittest.TestCase):
    """AssetsApi unit test stubs"""

    def setUp(self):
        self.api = AssetsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_asset(self):
        """Test case for create_asset

        Creates an asset  # noqa: E501
        """
        pass

    def test_create_asset_classification_category(self):
        """Test case for create_asset_classification_category

        Creates a category  # noqa: E501
        """
        pass

    def test_create_asset_classification_type(self):
        """Test case for create_asset_classification_type

        Creates an asset classification type  # noqa: E501
        """
        pass

    def test_delete_asset(self):
        """Test case for delete_asset

        Deletes an asset  # noqa: E501
        """
        pass

    def test_delete_asset_classification_category(self):
        """Test case for delete_asset_classification_category

        Deletes a category  # noqa: E501
        """
        pass

    def test_get_asset(self):
        """Test case for get_asset

        Gets an Asset  # noqa: E501
        """
        pass

    def test_get_asset_category_parameters(self):
        """Test case for get_asset_category_parameters

        Gets a list of Asset Classification parameters based on a given Category.  Includes any inherited parameters from any parent Categories.  # noqa: E501
        """
        pass

    def test_get_asset_classification_assignment(self):
        """Test case for get_asset_classification_assignment

        Gets the classification assignment for an asset  # noqa: E501
        """
        pass

    def test_get_asset_classification_categories(self):
        """Test case for get_asset_classification_categories

        Gets asset type categories.  # noqa: E501
        """
        pass

    def test_get_asset_classification_category(self):
        """Test case for get_asset_classification_category

        Gets a category by id  # noqa: E501
        """
        pass

    def test_get_asset_classification_type(self):
        """Test case for get_asset_classification_type

        Gets a type by id  # noqa: E501
        """
        pass

    def test_get_asset_classification_types(self):
        """Test case for get_asset_classification_types

        Gets a paged list of Asset Classification types  # noqa: E501
        """
        pass

    def test_get_asset_markers(self):
        """Test case for get_asset_markers

        Gets all markers on an asset  # noqa: E501
        """
        pass

    def test_get_asset_status(self):
        """Test case for get_asset_status

        Gets an asset's status  # noqa: E501
        """
        pass

    def test_get_asset_statuses(self):
        """Test case for get_asset_statuses

        Gets Asset Statuses  # noqa: E501
        """
        pass

    def test_get_asset_types(self):
        """Test case for get_asset_types

        This route is obsolete. Please use GET /api/v3.0/Assets/Classification/Types instead.  Gets Asset Types  # noqa: E501
        """
        pass

    def test_get_assets(self):
        """Test case for get_assets

        Gets Assets  # noqa: E501
        """
        pass

    def test_get_files_for_asset(self):
        """Test case for get_files_for_asset

        Gets an asset's files  # noqa: E501
        """
        pass

    def test_move_asset(self):
        """Test case for move_asset

        Moves an asset  # noqa: E501
        """
        pass

    def test_update_asset(self):
        """Test case for update_asset

        Updates an asset  # noqa: E501
        """
        pass

    def test_update_asset_classification_category(self):
        """Test case for update_asset_classification_category

        Updates a category  # noqa: E501
        """
        pass

    def test_update_asset_classification_parameters(self):
        """Test case for update_asset_classification_parameters

        Updates the parameters for a given category  # noqa: E501
        """
        pass

    def test_update_asset_classification_type(self):
        """Test case for update_asset_classification_type

        Updates an asset classification type  # noqa: E501
        """
        pass

    def test_update_classification_assignment(self):
        """Test case for update_classification_assignment

        Updates an assignment for classifications belonging to an asset.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CurrentUserUpdateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'accept_eula': 'bool',
        'first_name': 'str',
        'last_name': 'str',
        'phone_number': 'str',
        'phone_confirmation_code': 'str'
    }

    attribute_map = {
        'accept_eula': 'AcceptEula',
        'first_name': 'FirstName',
        'last_name': 'LastName',
        'phone_number': 'PhoneNumber',
        'phone_confirmation_code': 'PhoneConfirmationCode'
    }

    def __init__(self, accept_eula=None, first_name=None, last_name=None, phone_number=None, phone_confirmation_code=None):  # noqa: E501
        """CurrentUserUpdateRequest - a model defined in Swagger"""  # noqa: E501
        self._accept_eula = None
        self._first_name = None
        self._last_name = None
        self._phone_number = None
        self._phone_confirmation_code = None
        self.discriminator = None
        self.accept_eula = accept_eula
        self.first_name = first_name
        self.last_name = last_name
        if phone_number is not None:
            self.phone_number = phone_number
        if phone_confirmation_code is not None:
            self.phone_confirmation_code = phone_confirmation_code

    @property
    def accept_eula(self):
        """Gets the accept_eula of this CurrentUserUpdateRequest.  # noqa: E501

        If the EULA is accepted or declined  # noqa: E501

        :return: The accept_eula of this CurrentUserUpdateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._accept_eula

    @accept_eula.setter
    def accept_eula(self, accept_eula):
        """Sets the accept_eula of this CurrentUserUpdateRequest.

        If the EULA is accepted or declined  # noqa: E501

        :param accept_eula: The accept_eula of this CurrentUserUpdateRequest.  # noqa: E501
        :type: bool
        """
        if accept_eula is None:
            raise ValueError("Invalid value for `accept_eula`, must not be `None`")  # noqa: E501

        self._accept_eula = accept_eula

    @property
    def first_name(self):
        """Gets the first_name of this CurrentUserUpdateRequest.  # noqa: E501

        The user's first name  # noqa: E501

        :return: The first_name of this CurrentUserUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this CurrentUserUpdateRequest.

        The user's first name  # noqa: E501

        :param first_name: The first_name of this CurrentUserUpdateRequest.  # noqa: E501
        :type: str
        """
        if first_name is None:
            raise ValueError("Invalid value for `first_name`, must not be `None`")  # noqa: E501

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this CurrentUserUpdateRequest.  # noqa: E501

        The user's last name  # noqa: E501

        :return: The last_name of this CurrentUserUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this CurrentUserUpdateRequest.

        The user's last name  # noqa: E501

        :param last_name: The last_name of this CurrentUserUpdateRequest.  # noqa: E501
        :type: str
        """
        if last_name is None:
            raise ValueError("Invalid value for `last_name`, must not be `None`")  # noqa: E501

        self._last_name = last_name

    @property
    def phone_number(self):
        """Gets the phone_number of this CurrentUserUpdateRequest.  # noqa: E501

        User's phone number, formatted as [+][country code][area code][local phone number] (ex: +14151231234)  # noqa: E501

        :return: The phone_number of this CurrentUserUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this CurrentUserUpdateRequest.

        User's phone number, formatted as [+][country code][area code][local phone number] (ex: +14151231234)  # noqa: E501

        :param phone_number: The phone_number of this CurrentUserUpdateRequest.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    @property
    def phone_confirmation_code(self):
        """Gets the phone_confirmation_code of this CurrentUserUpdateRequest.  # noqa: E501

        Confirmation code from text message sent to user's phone. Must be included if changing a user's PhoneNumber  # noqa: E501

        :return: The phone_confirmation_code of this CurrentUserUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._phone_confirmation_code

    @phone_confirmation_code.setter
    def phone_confirmation_code(self, phone_confirmation_code):
        """Sets the phone_confirmation_code of this CurrentUserUpdateRequest.

        Confirmation code from text message sent to user's phone. Must be included if changing a user's PhoneNumber  # noqa: E501

        :param phone_confirmation_code: The phone_confirmation_code of this CurrentUserUpdateRequest.  # noqa: E501
        :type: str
        """

        self._phone_confirmation_code = phone_confirmation_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CurrentUserUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CurrentUserUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.base_stations_api import BaseStationsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestBaseStationsApi(unittest.TestCase):
    """BaseStationsApi unit test stubs"""

    def setUp(self):
        self.api = BaseStationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_base_station(self):
        """Test case for create_base_station

        Creates a Base Station  # noqa: E501
        """
        pass

    def test_edit_base_station(self):
        """Test case for edit_base_station

        """
        pass

    def test_export_base_stations(self):
        """Test case for export_base_stations

        Requests a Base Station export.  # noqa: E501
        """
        pass

    def test_get_base_station(self):
        """Test case for get_base_station

        Gets a Base Station by Id  # noqa: E501
        """
        pass

    def test_get_base_station_default_receiver_frequencies(self):
        """Test case for get_base_station_default_receiver_frequencies

        Returns a list of default Receiver Frequencies for a Base Station  # noqa: E501
        """
        pass

    def test_get_base_stations(self):
        """Test case for get_base_stations

        Gets a paged list of Base Stations  # noqa: E501
        """
        pass

    def test_reboot_base_station(self):
        """Test case for reboot_base_station

        Reboots a given Base station  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.monitoring_points_api import MonitoringPointsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestMonitoringPointsApi(unittest.TestCase):
    """MonitoringPointsApi unit test stubs"""

    def setUp(self):
        self.api = MonitoringPointsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_monitoring_point(self):
        """Test case for create_monitoring_point

        Creates a monitoringPoint  # noqa: E501
        """
        pass

    def test_delete_monitoring_point(self):
        """Test case for delete_monitoring_point

        Deletes a monitoringPoint  # noqa: E501
        """
        pass

    def test_get_monitoring_point(self):
        """Test case for get_monitoring_point

        Gets a Monitoring Point  # noqa: E501
        """
        pass

    def test_get_monitoring_point_assignments(self):
        """Test case for get_monitoring_point_assignments

        Gets all of the node assignment history for a monitoring point including the current assignment.  # noqa: E501
        """
        pass

    def test_get_monitoring_point_current_assignment(self):
        """Test case for get_monitoring_point_current_assignment

        Gets the currently assigned node to a monitoring point  # noqa: E501
        """
        pass

    def test_get_monitoring_point_overview(self):
        """Test case for get_monitoring_point_overview

        Gets an overview of monitoring point(s) which includes the node settings  # noqa: E501
        """
        pass

    def test_get_monitoring_points(self):
        """Test case for get_monitoring_points

        Gets Monitoring Points  # noqa: E501
        """
        pass

    def test_update_monitoring_point(self):
        """Test case for update_monitoring_point

        Updates a monitoringPoint  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.identity_providers_api import IdentityProvidersApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestIdentityProvidersApi(unittest.TestCase):
    """IdentityProvidersApi unit test stubs"""

    def setUp(self):
        self.api = IdentityProvidersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_identity_provider(self):
        """Test case for create_identity_provider

        Creates a new identity provider  # noqa: E501
        """
        pass

    def test_get_identity_provider(self):
        """Test case for get_identity_provider

        Gets the identity provider with the provided ID  # noqa: E501
        """
        pass

    def test_get_identity_providers(self):
        """Test case for get_identity_providers

        Gets all identity providers  # noqa: E501
        """
        pass

    def test_update_identity_provider(self):
        """Test case for update_identity_provider

        Edits an identity provider  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AssetClassificationAssignmentUpdateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asset_type_id': 'int',
        'asset_category_id': 'int',
        'parameter_values': 'list[AssetClassificationParameterValueChild]'
    }

    attribute_map = {
        'asset_type_id': 'AssetTypeId',
        'asset_category_id': 'AssetCategoryId',
        'parameter_values': 'ParameterValues'
    }

    def __init__(self, asset_type_id=None, asset_category_id=None, parameter_values=None):  # noqa: E501
        """AssetClassificationAssignmentUpdateRequest - a model defined in Swagger"""  # noqa: E501
        self._asset_type_id = None
        self._asset_category_id = None
        self._parameter_values = None
        self.discriminator = None
        if asset_type_id is not None:
            self.asset_type_id = asset_type_id
        if asset_category_id is not None:
            self.asset_category_id = asset_category_id
        if parameter_values is not None:
            self.parameter_values = parameter_values

    @property
    def asset_type_id(self):
        """Gets the asset_type_id of this AssetClassificationAssignmentUpdateRequest.  # noqa: E501


        :return: The asset_type_id of this AssetClassificationAssignmentUpdateRequest.  # noqa: E501
        :rtype: int
        """
        return self._asset_type_id

    @asset_type_id.setter
    def asset_type_id(self, asset_type_id):
        """Sets the asset_type_id of this AssetClassificationAssignmentUpdateRequest.


        :param asset_type_id: The asset_type_id of this AssetClassificationAssignmentUpdateRequest.  # noqa: E501
        :type: int
        """

        self._asset_type_id = asset_type_id

    @property
    def asset_category_id(self):
        """Gets the asset_category_id of this AssetClassificationAssignmentUpdateRequest.  # noqa: E501


        :return: The asset_category_id of this AssetClassificationAssignmentUpdateRequest.  # noqa: E501
        :rtype: int
        """
        return self._asset_category_id

    @asset_category_id.setter
    def asset_category_id(self, asset_category_id):
        """Sets the asset_category_id of this AssetClassificationAssignmentUpdateRequest.


        :param asset_category_id: The asset_category_id of this AssetClassificationAssignmentUpdateRequest.  # noqa: E501
        :type: int
        """

        self._asset_category_id = asset_category_id

    @property
    def parameter_values(self):
        """Gets the parameter_values of this AssetClassificationAssignmentUpdateRequest.  # noqa: E501


        :return: The parameter_values of this AssetClassificationAssignmentUpdateRequest.  # noqa: E501
        :rtype: list[AssetClassificationParameterValueChild]
        """
        return self._parameter_values

    @parameter_values.setter
    def parameter_values(self, parameter_values):
        """Sets the parameter_values of this AssetClassificationAssignmentUpdateRequest.


        :param parameter_values: The parameter_values of this AssetClassificationAssignmentUpdateRequest.  # noqa: E501
        :type: list[AssetClassificationParameterValueChild]
        """

        self._parameter_values = parameter_values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AssetClassificationAssignmentUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetClassificationAssignmentUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ActivityEventHierarchyGroupRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'start_date_time': 'datetime',
        'end_date_time': 'datetime',
        'indicator_ids': 'list[str]',
        'group_ids': 'list[str]',
        'category_ids': 'list[int]',
        'category_flags': 'list[ActivityEventCategoryFlag]',
        'activity_line_enabled': 'bool',
        'location_id': 'str'
    }

    attribute_map = {
        'start_date_time': 'StartDateTime',
        'end_date_time': 'EndDateTime',
        'indicator_ids': 'IndicatorIds',
        'group_ids': 'GroupIds',
        'category_ids': 'CategoryIds',
        'category_flags': 'CategoryFlags',
        'activity_line_enabled': 'ActivityLineEnabled',
        'location_id': 'LocationId'
    }

    def __init__(self, start_date_time=None, end_date_time=None, indicator_ids=None, group_ids=None, category_ids=None, category_flags=None, activity_line_enabled=None, location_id=None):  # noqa: E501
        """ActivityEventHierarchyGroupRequest - a model defined in Swagger"""  # noqa: E501
        self._start_date_time = None
        self._end_date_time = None
        self._indicator_ids = None
        self._group_ids = None
        self._category_ids = None
        self._category_flags = None
        self._activity_line_enabled = None
        self._location_id = None
        self.discriminator = None
        self.start_date_time = start_date_time
        self.end_date_time = end_date_time
        if indicator_ids is not None:
            self.indicator_ids = indicator_ids
        if group_ids is not None:
            self.group_ids = group_ids
        if category_ids is not None:
            self.category_ids = category_ids
        if category_flags is not None:
            self.category_flags = category_flags
        if activity_line_enabled is not None:
            self.activity_line_enabled = activity_line_enabled
        if location_id is not None:
            self.location_id = location_id

    @property
    def start_date_time(self):
        """Gets the start_date_time of this ActivityEventHierarchyGroupRequest.  # noqa: E501


        :return: The start_date_time of this ActivityEventHierarchyGroupRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date_time

    @start_date_time.setter
    def start_date_time(self, start_date_time):
        """Sets the start_date_time of this ActivityEventHierarchyGroupRequest.


        :param start_date_time: The start_date_time of this ActivityEventHierarchyGroupRequest.  # noqa: E501
        :type: datetime
        """
        if start_date_time is None:
            raise ValueError("Invalid value for `start_date_time`, must not be `None`")  # noqa: E501

        self._start_date_time = start_date_time

    @property
    def end_date_time(self):
        """Gets the end_date_time of this ActivityEventHierarchyGroupRequest.  # noqa: E501


        :return: The end_date_time of this ActivityEventHierarchyGroupRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date_time

    @end_date_time.setter
    def end_date_time(self, end_date_time):
        """Sets the end_date_time of this ActivityEventHierarchyGroupRequest.


        :param end_date_time: The end_date_time of this ActivityEventHierarchyGroupRequest.  # noqa: E501
        :type: datetime
        """
        if end_date_time is None:
            raise ValueError("Invalid value for `end_date_time`, must not be `None`")  # noqa: E501

        self._end_date_time = end_date_time

    @property
    def indicator_ids(self):
        """Gets the indicator_ids of this ActivityEventHierarchyGroupRequest.  # noqa: E501


        :return: The indicator_ids of this ActivityEventHierarchyGroupRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._indicator_ids

    @indicator_ids.setter
    def indicator_ids(self, indicator_ids):
        """Sets the indicator_ids of this ActivityEventHierarchyGroupRequest.


        :param indicator_ids: The indicator_ids of this ActivityEventHierarchyGroupRequest.  # noqa: E501
        :type: list[str]
        """

        self._indicator_ids = indicator_ids

    @property
    def group_ids(self):
        """Gets the group_ids of this ActivityEventHierarchyGroupRequest.  # noqa: E501


        :return: The group_ids of this ActivityEventHierarchyGroupRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._group_ids

    @group_ids.setter
    def group_ids(self, group_ids):
        """Sets the group_ids of this ActivityEventHierarchyGroupRequest.


        :param group_ids: The group_ids of this ActivityEventHierarchyGroupRequest.  # noqa: E501
        :type: list[str]
        """

        self._group_ids = group_ids

    @property
    def category_ids(self):
        """Gets the category_ids of this ActivityEventHierarchyGroupRequest.  # noqa: E501


        :return: The category_ids of this ActivityEventHierarchyGroupRequest.  # noqa: E501
        :rtype: list[int]
        """
        return self._category_ids

    @category_ids.setter
    def category_ids(self, category_ids):
        """Sets the category_ids of this ActivityEventHierarchyGroupRequest.


        :param category_ids: The category_ids of this ActivityEventHierarchyGroupRequest.  # noqa: E501
        :type: list[int]
        """

        self._category_ids = category_ids

    @property
    def category_flags(self):
        """Gets the category_flags of this ActivityEventHierarchyGroupRequest.  # noqa: E501


        :return: The category_flags of this ActivityEventHierarchyGroupRequest.  # noqa: E501
        :rtype: list[ActivityEventCategoryFlag]
        """
        return self._category_flags

    @category_flags.setter
    def category_flags(self, category_flags):
        """Sets the category_flags of this ActivityEventHierarchyGroupRequest.


        :param category_flags: The category_flags of this ActivityEventHierarchyGroupRequest.  # noqa: E501
        :type: list[ActivityEventCategoryFlag]
        """

        self._category_flags = category_flags

    @property
    def activity_line_enabled(self):
        """Gets the activity_line_enabled of this ActivityEventHierarchyGroupRequest.  # noqa: E501


        :return: The activity_line_enabled of this ActivityEventHierarchyGroupRequest.  # noqa: E501
        :rtype: bool
        """
        return self._activity_line_enabled

    @activity_line_enabled.setter
    def activity_line_enabled(self, activity_line_enabled):
        """Sets the activity_line_enabled of this ActivityEventHierarchyGroupRequest.


        :param activity_line_enabled: The activity_line_enabled of this ActivityEventHierarchyGroupRequest.  # noqa: E501
        :type: bool
        """

        self._activity_line_enabled = activity_line_enabled

    @property
    def location_id(self):
        """Gets the location_id of this ActivityEventHierarchyGroupRequest.  # noqa: E501


        :return: The location_id of this ActivityEventHierarchyGroupRequest.  # noqa: E501
        :rtype: str
        """
        return self._location_id

    @location_id.setter
    def location_id(self, location_id):
        """Sets the location_id of this ActivityEventHierarchyGroupRequest.


        :param location_id: The location_id of this ActivityEventHierarchyGroupRequest.  # noqa: E501
        :type: str
        """

        self._location_id = location_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ActivityEventHierarchyGroupRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActivityEventHierarchyGroupRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.filters_api import FiltersApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestFiltersApi(unittest.TestCase):
    """FiltersApi unit test stubs"""

    def setUp(self):
        self.api = FiltersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_indicator_filter(self):
        """Test case for create_indicator_filter

        Creates an indicator filter  # noqa: E501
        """
        pass

    def test_delete_indicator_filter(self):
        """Test case for delete_indicator_filter

        Deletes an indicator filter  # noqa: E501
        """
        pass

    def test_get_indicator_filter(self):
        """Test case for get_indicator_filter

        Gets a single indicator filter  # noqa: E501
        """
        pass

    def test_get_indicator_filters(self):
        """Test case for get_indicator_filters

        Gets many indicator filters  # noqa: E501
        """
        pass

    def test_update_indicator_filter(self):
        """Test case for update_indicator_filter

        Updates an indicator filter  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class StatusChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status_id': 'str',
        'status_name': 'str',
        'status_color': 'str',
        'status_icon': 'str',
        'status_active': 'bool',
        'status_is_custom': 'bool',
        'status_sort_order': 'int'
    }

    attribute_map = {
        'status_id': 'StatusId',
        'status_name': 'StatusName',
        'status_color': 'StatusColor',
        'status_icon': 'StatusIcon',
        'status_active': 'StatusActive',
        'status_is_custom': 'StatusIsCustom',
        'status_sort_order': 'StatusSortOrder'
    }

    def __init__(self, status_id=None, status_name=None, status_color=None, status_icon=None, status_active=None, status_is_custom=None, status_sort_order=None):  # noqa: E501
        """StatusChild - a model defined in Swagger"""  # noqa: E501
        self._status_id = None
        self._status_name = None
        self._status_color = None
        self._status_icon = None
        self._status_active = None
        self._status_is_custom = None
        self._status_sort_order = None
        self.discriminator = None
        self.status_id = status_id
        self.status_name = status_name
        self.status_color = status_color
        if status_icon is not None:
            self.status_icon = status_icon
        self.status_active = status_active
        self.status_is_custom = status_is_custom
        if status_sort_order is not None:
            self.status_sort_order = status_sort_order

    @property
    def status_id(self):
        """Gets the status_id of this StatusChild.  # noqa: E501

        The id of the status  # noqa: E501

        :return: The status_id of this StatusChild.  # noqa: E501
        :rtype: str
        """
        return self._status_id

    @status_id.setter
    def status_id(self, status_id):
        """Sets the status_id of this StatusChild.

        The id of the status  # noqa: E501

        :param status_id: The status_id of this StatusChild.  # noqa: E501
        :type: str
        """
        if status_id is None:
            raise ValueError("Invalid value for `status_id`, must not be `None`")  # noqa: E501

        self._status_id = status_id

    @property
    def status_name(self):
        """Gets the status_name of this StatusChild.  # noqa: E501

        The name of the status  # noqa: E501

        :return: The status_name of this StatusChild.  # noqa: E501
        :rtype: str
        """
        return self._status_name

    @status_name.setter
    def status_name(self, status_name):
        """Sets the status_name of this StatusChild.

        The name of the status  # noqa: E501

        :param status_name: The status_name of this StatusChild.  # noqa: E501
        :type: str
        """
        if status_name is None:
            raise ValueError("Invalid value for `status_name`, must not be `None`")  # noqa: E501

        self._status_name = status_name

    @property
    def status_color(self):
        """Gets the status_color of this StatusChild.  # noqa: E501

        The color of the status in hex  # noqa: E501

        :return: The status_color of this StatusChild.  # noqa: E501
        :rtype: str
        """
        return self._status_color

    @status_color.setter
    def status_color(self, status_color):
        """Sets the status_color of this StatusChild.

        The color of the status in hex  # noqa: E501

        :param status_color: The status_color of this StatusChild.  # noqa: E501
        :type: str
        """
        if status_color is None:
            raise ValueError("Invalid value for `status_color`, must not be `None`")  # noqa: E501

        self._status_color = status_color

    @property
    def status_icon(self):
        """Gets the status_icon of this StatusChild.  # noqa: E501

        The fontawesome icon name of the status  # noqa: E501

        :return: The status_icon of this StatusChild.  # noqa: E501
        :rtype: str
        """
        return self._status_icon

    @status_icon.setter
    def status_icon(self, status_icon):
        """Sets the status_icon of this StatusChild.

        The fontawesome icon name of the status  # noqa: E501

        :param status_icon: The status_icon of this StatusChild.  # noqa: E501
        :type: str
        """

        self._status_icon = status_icon

    @property
    def status_active(self):
        """Gets the status_active of this StatusChild.  # noqa: E501

        Whether the status is active  # noqa: E501

        :return: The status_active of this StatusChild.  # noqa: E501
        :rtype: bool
        """
        return self._status_active

    @status_active.setter
    def status_active(self, status_active):
        """Sets the status_active of this StatusChild.

        Whether the status is active  # noqa: E501

        :param status_active: The status_active of this StatusChild.  # noqa: E501
        :type: bool
        """
        if status_active is None:
            raise ValueError("Invalid value for `status_active`, must not be `None`")  # noqa: E501

        self._status_active = status_active

    @property
    def status_is_custom(self):
        """Gets the status_is_custom of this StatusChild.  # noqa: E501

        Whether the status is custom  # noqa: E501

        :return: The status_is_custom of this StatusChild.  # noqa: E501
        :rtype: bool
        """
        return self._status_is_custom

    @status_is_custom.setter
    def status_is_custom(self, status_is_custom):
        """Sets the status_is_custom of this StatusChild.

        Whether the status is custom  # noqa: E501

        :param status_is_custom: The status_is_custom of this StatusChild.  # noqa: E501
        :type: bool
        """
        if status_is_custom is None:
            raise ValueError("Invalid value for `status_is_custom`, must not be `None`")  # noqa: E501

        self._status_is_custom = status_is_custom

    @property
    def status_sort_order(self):
        """Gets the status_sort_order of this StatusChild.  # noqa: E501

        The sort order for the status  # noqa: E501

        :return: The status_sort_order of this StatusChild.  # noqa: E501
        :rtype: int
        """
        return self._status_sort_order

    @status_sort_order.setter
    def status_sort_order(self, status_sort_order):
        """Sets the status_sort_order of this StatusChild.

        The sort order for the status  # noqa: E501

        :param status_sort_order: The status_sort_order of this StatusChild.  # noqa: E501
        :type: int
        """

        self._status_sort_order = status_sort_order

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StatusChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StatusChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class LocationResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'abbreviation': 'str',
        'active': 'bool',
        'created': 'datetime',
        'api_key': 'str',
        'site_ids': 'list[str]',
        'settings': 'LocationSettingsChild',
        'location_permissions': 'LocationPermissionsResponse',
        'corporation': 'PrimaryCorporationChild',
        'systems': 'list[SystemChild]'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'abbreviation': 'Abbreviation',
        'active': 'Active',
        'created': 'Created',
        'api_key': 'ApiKey',
        'site_ids': 'SiteIds',
        'settings': 'Settings',
        'location_permissions': 'LocationPermissions',
        'corporation': 'Corporation',
        'systems': 'Systems'
    }

    def __init__(self, id=None, name=None, abbreviation=None, active=None, created=None, api_key=None, site_ids=None, settings=None, location_permissions=None, corporation=None, systems=None):  # noqa: E501
        """LocationResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._abbreviation = None
        self._active = None
        self._created = None
        self._api_key = None
        self._site_ids = None
        self._settings = None
        self._location_permissions = None
        self._corporation = None
        self._systems = None
        self.discriminator = None
        self.id = id
        self.name = name
        if abbreviation is not None:
            self.abbreviation = abbreviation
        self.active = active
        self.created = created
        if api_key is not None:
            self.api_key = api_key
        self.site_ids = site_ids
        self.settings = settings
        self.location_permissions = location_permissions
        self.corporation = corporation
        self.systems = systems

    @property
    def id(self):
        """Gets the id of this LocationResponse.  # noqa: E501

        Id of the location  # noqa: E501

        :return: The id of this LocationResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this LocationResponse.

        Id of the location  # noqa: E501

        :param id: The id of this LocationResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this LocationResponse.  # noqa: E501

        Location's name  # noqa: E501

        :return: The name of this LocationResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this LocationResponse.

        Location's name  # noqa: E501

        :param name: The name of this LocationResponse.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def abbreviation(self):
        """Gets the abbreviation of this LocationResponse.  # noqa: E501

        Location's abbreviation  # noqa: E501

        :return: The abbreviation of this LocationResponse.  # noqa: E501
        :rtype: str
        """
        return self._abbreviation

    @abbreviation.setter
    def abbreviation(self, abbreviation):
        """Sets the abbreviation of this LocationResponse.

        Location's abbreviation  # noqa: E501

        :param abbreviation: The abbreviation of this LocationResponse.  # noqa: E501
        :type: str
        """

        self._abbreviation = abbreviation

    @property
    def active(self):
        """Gets the active of this LocationResponse.  # noqa: E501

        If the location is active  # noqa: E501

        :return: The active of this LocationResponse.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this LocationResponse.

        If the location is active  # noqa: E501

        :param active: The active of this LocationResponse.  # noqa: E501
        :type: bool
        """
        if active is None:
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    @property
    def created(self):
        """Gets the created of this LocationResponse.  # noqa: E501

        When the location was created  # noqa: E501

        :return: The created of this LocationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this LocationResponse.

        When the location was created  # noqa: E501

        :param created: The created of this LocationResponse.  # noqa: E501
        :type: datetime
        """
        if created is None:
            raise ValueError("Invalid value for `created`, must not be `None`")  # noqa: E501

        self._created = created

    @property
    def api_key(self):
        """Gets the api_key of this LocationResponse.  # noqa: E501

        The location's API key  # noqa: E501

        :return: The api_key of this LocationResponse.  # noqa: E501
        :rtype: str
        """
        return self._api_key

    @api_key.setter
    def api_key(self, api_key):
        """Sets the api_key of this LocationResponse.

        The location's API key  # noqa: E501

        :param api_key: The api_key of this LocationResponse.  # noqa: E501
        :type: str
        """

        self._api_key = api_key

    @property
    def site_ids(self):
        """Gets the site_ids of this LocationResponse.  # noqa: E501

        The location's siteIds  # noqa: E501

        :return: The site_ids of this LocationResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._site_ids

    @site_ids.setter
    def site_ids(self, site_ids):
        """Sets the site_ids of this LocationResponse.

        The location's siteIds  # noqa: E501

        :param site_ids: The site_ids of this LocationResponse.  # noqa: E501
        :type: list[str]
        """
        if site_ids is None:
            raise ValueError("Invalid value for `site_ids`, must not be `None`")  # noqa: E501

        self._site_ids = site_ids

    @property
    def settings(self):
        """Gets the settings of this LocationResponse.  # noqa: E501


        :return: The settings of this LocationResponse.  # noqa: E501
        :rtype: LocationSettingsChild
        """
        return self._settings

    @settings.setter
    def settings(self, settings):
        """Sets the settings of this LocationResponse.


        :param settings: The settings of this LocationResponse.  # noqa: E501
        :type: LocationSettingsChild
        """
        if settings is None:
            raise ValueError("Invalid value for `settings`, must not be `None`")  # noqa: E501

        self._settings = settings

    @property
    def location_permissions(self):
        """Gets the location_permissions of this LocationResponse.  # noqa: E501


        :return: The location_permissions of this LocationResponse.  # noqa: E501
        :rtype: LocationPermissionsResponse
        """
        return self._location_permissions

    @location_permissions.setter
    def location_permissions(self, location_permissions):
        """Sets the location_permissions of this LocationResponse.


        :param location_permissions: The location_permissions of this LocationResponse.  # noqa: E501
        :type: LocationPermissionsResponse
        """
        if location_permissions is None:
            raise ValueError("Invalid value for `location_permissions`, must not be `None`")  # noqa: E501

        self._location_permissions = location_permissions

    @property
    def corporation(self):
        """Gets the corporation of this LocationResponse.  # noqa: E501


        :return: The corporation of this LocationResponse.  # noqa: E501
        :rtype: PrimaryCorporationChild
        """
        return self._corporation

    @corporation.setter
    def corporation(self, corporation):
        """Sets the corporation of this LocationResponse.


        :param corporation: The corporation of this LocationResponse.  # noqa: E501
        :type: PrimaryCorporationChild
        """
        if corporation is None:
            raise ValueError("Invalid value for `corporation`, must not be `None`")  # noqa: E501

        self._corporation = corporation

    @property
    def systems(self):
        """Gets the systems of this LocationResponse.  # noqa: E501

        The systems in the location  # noqa: E501

        :return: The systems of this LocationResponse.  # noqa: E501
        :rtype: list[SystemChild]
        """
        return self._systems

    @systems.setter
    def systems(self, systems):
        """Sets the systems of this LocationResponse.

        The systems in the location  # noqa: E501

        :param systems: The systems of this LocationResponse.  # noqa: E501
        :type: list[SystemChild]
        """
        if systems is None:
            raise ValueError("Invalid value for `systems`, must not be `None`")  # noqa: E501

        self._systems = systems

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LocationResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LocationResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AlertResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'time_of_alert': 'datetime',
        'is_acknowledged': 'bool',
        'time_acknowledged': 'datetime',
        'acknowledge_by_user': 'UserChild',
        'alert_type': 'AlertType',
        'external_notification': 'ExternalNotificationChild',
        'indicator': 'IndicatorChild',
        'hierarchy': 'list[HierarchyChild]',
        'location': 'LocationChild'
    }

    attribute_map = {
        'id': 'Id',
        'time_of_alert': 'TimeOfAlert',
        'is_acknowledged': 'IsAcknowledged',
        'time_acknowledged': 'TimeAcknowledged',
        'acknowledge_by_user': 'AcknowledgeByUser',
        'alert_type': 'AlertType',
        'external_notification': 'ExternalNotification',
        'indicator': 'Indicator',
        'hierarchy': 'Hierarchy',
        'location': 'Location'
    }

    def __init__(self, id=None, time_of_alert=None, is_acknowledged=None, time_acknowledged=None, acknowledge_by_user=None, alert_type=None, external_notification=None, indicator=None, hierarchy=None, location=None):  # noqa: E501
        """AlertResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._time_of_alert = None
        self._is_acknowledged = None
        self._time_acknowledged = None
        self._acknowledge_by_user = None
        self._alert_type = None
        self._external_notification = None
        self._indicator = None
        self._hierarchy = None
        self._location = None
        self.discriminator = None
        self.id = id
        self.time_of_alert = time_of_alert
        self.is_acknowledged = is_acknowledged
        if time_acknowledged is not None:
            self.time_acknowledged = time_acknowledged
        if acknowledge_by_user is not None:
            self.acknowledge_by_user = acknowledge_by_user
        self.alert_type = alert_type
        if external_notification is not None:
            self.external_notification = external_notification
        self.indicator = indicator
        self.hierarchy = hierarchy
        self.location = location

    @property
    def id(self):
        """Gets the id of this AlertResponse.  # noqa: E501

        The unique Id for the Alert  # noqa: E501

        :return: The id of this AlertResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AlertResponse.

        The unique Id for the Alert  # noqa: E501

        :param id: The id of this AlertResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def time_of_alert(self):
        """Gets the time_of_alert of this AlertResponse.  # noqa: E501

        The time the alert was created  # noqa: E501

        :return: The time_of_alert of this AlertResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._time_of_alert

    @time_of_alert.setter
    def time_of_alert(self, time_of_alert):
        """Sets the time_of_alert of this AlertResponse.

        The time the alert was created  # noqa: E501

        :param time_of_alert: The time_of_alert of this AlertResponse.  # noqa: E501
        :type: datetime
        """
        if time_of_alert is None:
            raise ValueError("Invalid value for `time_of_alert`, must not be `None`")  # noqa: E501

        self._time_of_alert = time_of_alert

    @property
    def is_acknowledged(self):
        """Gets the is_acknowledged of this AlertResponse.  # noqa: E501

        Determines whether or not the alert has been acknowledged  # noqa: E501

        :return: The is_acknowledged of this AlertResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_acknowledged

    @is_acknowledged.setter
    def is_acknowledged(self, is_acknowledged):
        """Sets the is_acknowledged of this AlertResponse.

        Determines whether or not the alert has been acknowledged  # noqa: E501

        :param is_acknowledged: The is_acknowledged of this AlertResponse.  # noqa: E501
        :type: bool
        """
        if is_acknowledged is None:
            raise ValueError("Invalid value for `is_acknowledged`, must not be `None`")  # noqa: E501

        self._is_acknowledged = is_acknowledged

    @property
    def time_acknowledged(self):
        """Gets the time_acknowledged of this AlertResponse.  # noqa: E501

        The time the alert was acknowledged by the user  # noqa: E501

        :return: The time_acknowledged of this AlertResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._time_acknowledged

    @time_acknowledged.setter
    def time_acknowledged(self, time_acknowledged):
        """Sets the time_acknowledged of this AlertResponse.

        The time the alert was acknowledged by the user  # noqa: E501

        :param time_acknowledged: The time_acknowledged of this AlertResponse.  # noqa: E501
        :type: datetime
        """

        self._time_acknowledged = time_acknowledged

    @property
    def acknowledge_by_user(self):
        """Gets the acknowledge_by_user of this AlertResponse.  # noqa: E501


        :return: The acknowledge_by_user of this AlertResponse.  # noqa: E501
        :rtype: UserChild
        """
        return self._acknowledge_by_user

    @acknowledge_by_user.setter
    def acknowledge_by_user(self, acknowledge_by_user):
        """Sets the acknowledge_by_user of this AlertResponse.


        :param acknowledge_by_user: The acknowledge_by_user of this AlertResponse.  # noqa: E501
        :type: UserChild
        """

        self._acknowledge_by_user = acknowledge_by_user

    @property
    def alert_type(self):
        """Gets the alert_type of this AlertResponse.  # noqa: E501


        :return: The alert_type of this AlertResponse.  # noqa: E501
        :rtype: AlertType
        """
        return self._alert_type

    @alert_type.setter
    def alert_type(self, alert_type):
        """Sets the alert_type of this AlertResponse.


        :param alert_type: The alert_type of this AlertResponse.  # noqa: E501
        :type: AlertType
        """
        if alert_type is None:
            raise ValueError("Invalid value for `alert_type`, must not be `None`")  # noqa: E501

        self._alert_type = alert_type

    @property
    def external_notification(self):
        """Gets the external_notification of this AlertResponse.  # noqa: E501


        :return: The external_notification of this AlertResponse.  # noqa: E501
        :rtype: ExternalNotificationChild
        """
        return self._external_notification

    @external_notification.setter
    def external_notification(self, external_notification):
        """Sets the external_notification of this AlertResponse.


        :param external_notification: The external_notification of this AlertResponse.  # noqa: E501
        :type: ExternalNotificationChild
        """

        self._external_notification = external_notification

    @property
    def indicator(self):
        """Gets the indicator of this AlertResponse.  # noqa: E501


        :return: The indicator of this AlertResponse.  # noqa: E501
        :rtype: IndicatorChild
        """
        return self._indicator

    @indicator.setter
    def indicator(self, indicator):
        """Sets the indicator of this AlertResponse.


        :param indicator: The indicator of this AlertResponse.  # noqa: E501
        :type: IndicatorChild
        """
        if indicator is None:
            raise ValueError("Invalid value for `indicator`, must not be `None`")  # noqa: E501

        self._indicator = indicator

    @property
    def hierarchy(self):
        """Gets the hierarchy of this AlertResponse.  # noqa: E501

        The list of the parent groups for the indicator  # noqa: E501

        :return: The hierarchy of this AlertResponse.  # noqa: E501
        :rtype: list[HierarchyChild]
        """
        return self._hierarchy

    @hierarchy.setter
    def hierarchy(self, hierarchy):
        """Sets the hierarchy of this AlertResponse.

        The list of the parent groups for the indicator  # noqa: E501

        :param hierarchy: The hierarchy of this AlertResponse.  # noqa: E501
        :type: list[HierarchyChild]
        """
        if hierarchy is None:
            raise ValueError("Invalid value for `hierarchy`, must not be `None`")  # noqa: E501

        self._hierarchy = hierarchy

    @property
    def location(self):
        """Gets the location of this AlertResponse.  # noqa: E501


        :return: The location of this AlertResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this AlertResponse.


        :param location: The location of this AlertResponse.  # noqa: E501
        :type: LocationChild
        """
        if location is None:
            raise ValueError("Invalid value for `location`, must not be `None`")  # noqa: E501

        self._location = location

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AlertResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AlertResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BaseStationResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'serial_number': 'str',
        'name': 'str',
        'location': 'LocationChild',
        'corporation': 'CorporationChild',
        'last_status_update': 'datetime',
        'push_to_stage': 'bool',
        'release_ring': 'ReleaseRingChild',
        'targeted_software_release': 'TargetedSoftwareReleaseChild',
        'current_software_release': 'CurrentSoftwareReleaseChild',
        'hardware_revision': 'HardwareRevisionChild',
        'receiver': 'BaseStationReceiverChild',
        'repeaters': 'list[RepeaterChild]',
        'total_online_node_count': 'int',
        'allowed_auto_frequencies': 'list[str]',
        'last_data_update': 'datetime',
        'is_online': 'bool'
    }

    attribute_map = {
        'id': 'Id',
        'serial_number': 'SerialNumber',
        'name': 'Name',
        'location': 'Location',
        'corporation': 'Corporation',
        'last_status_update': 'LastStatusUpdate',
        'push_to_stage': 'PushToStage',
        'release_ring': 'ReleaseRing',
        'targeted_software_release': 'TargetedSoftwareRelease',
        'current_software_release': 'CurrentSoftwareRelease',
        'hardware_revision': 'HardwareRevision',
        'receiver': 'Receiver',
        'repeaters': 'Repeaters',
        'total_online_node_count': 'TotalOnlineNodeCount',
        'allowed_auto_frequencies': 'AllowedAutoFrequencies',
        'last_data_update': 'LastDataUpdate',
        'is_online': 'IsOnline'
    }

    def __init__(self, id=None, serial_number=None, name=None, location=None, corporation=None, last_status_update=None, push_to_stage=None, release_ring=None, targeted_software_release=None, current_software_release=None, hardware_revision=None, receiver=None, repeaters=None, total_online_node_count=None, allowed_auto_frequencies=None, last_data_update=None, is_online=None):  # noqa: E501
        """BaseStationResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._serial_number = None
        self._name = None
        self._location = None
        self._corporation = None
        self._last_status_update = None
        self._push_to_stage = None
        self._release_ring = None
        self._targeted_software_release = None
        self._current_software_release = None
        self._hardware_revision = None
        self._receiver = None
        self._repeaters = None
        self._total_online_node_count = None
        self._allowed_auto_frequencies = None
        self._last_data_update = None
        self._is_online = None
        self.discriminator = None
        self.id = id
        self.serial_number = serial_number
        if name is not None:
            self.name = name
        self.location = location
        self.corporation = corporation
        if last_status_update is not None:
            self.last_status_update = last_status_update
        self.push_to_stage = push_to_stage
        if release_ring is not None:
            self.release_ring = release_ring
        if targeted_software_release is not None:
            self.targeted_software_release = targeted_software_release
        if current_software_release is not None:
            self.current_software_release = current_software_release
        if hardware_revision is not None:
            self.hardware_revision = hardware_revision
        if receiver is not None:
            self.receiver = receiver
        self.repeaters = repeaters
        self.total_online_node_count = total_online_node_count
        self.allowed_auto_frequencies = allowed_auto_frequencies
        if last_data_update is not None:
            self.last_data_update = last_data_update
        if is_online is not None:
            self.is_online = is_online

    @property
    def id(self):
        """Gets the id of this BaseStationResponse.  # noqa: E501


        :return: The id of this BaseStationResponse.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BaseStationResponse.


        :param id: The id of this BaseStationResponse.  # noqa: E501
        :type: int
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def serial_number(self):
        """Gets the serial_number of this BaseStationResponse.  # noqa: E501


        :return: The serial_number of this BaseStationResponse.  # noqa: E501
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """Sets the serial_number of this BaseStationResponse.


        :param serial_number: The serial_number of this BaseStationResponse.  # noqa: E501
        :type: str
        """
        if serial_number is None:
            raise ValueError("Invalid value for `serial_number`, must not be `None`")  # noqa: E501

        self._serial_number = serial_number

    @property
    def name(self):
        """Gets the name of this BaseStationResponse.  # noqa: E501


        :return: The name of this BaseStationResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BaseStationResponse.


        :param name: The name of this BaseStationResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def location(self):
        """Gets the location of this BaseStationResponse.  # noqa: E501


        :return: The location of this BaseStationResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this BaseStationResponse.


        :param location: The location of this BaseStationResponse.  # noqa: E501
        :type: LocationChild
        """
        if location is None:
            raise ValueError("Invalid value for `location`, must not be `None`")  # noqa: E501

        self._location = location

    @property
    def corporation(self):
        """Gets the corporation of this BaseStationResponse.  # noqa: E501


        :return: The corporation of this BaseStationResponse.  # noqa: E501
        :rtype: CorporationChild
        """
        return self._corporation

    @corporation.setter
    def corporation(self, corporation):
        """Sets the corporation of this BaseStationResponse.


        :param corporation: The corporation of this BaseStationResponse.  # noqa: E501
        :type: CorporationChild
        """
        if corporation is None:
            raise ValueError("Invalid value for `corporation`, must not be `None`")  # noqa: E501

        self._corporation = corporation

    @property
    def last_status_update(self):
        """Gets the last_status_update of this BaseStationResponse.  # noqa: E501


        :return: The last_status_update of this BaseStationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._last_status_update

    @last_status_update.setter
    def last_status_update(self, last_status_update):
        """Sets the last_status_update of this BaseStationResponse.


        :param last_status_update: The last_status_update of this BaseStationResponse.  # noqa: E501
        :type: datetime
        """

        self._last_status_update = last_status_update

    @property
    def push_to_stage(self):
        """Gets the push_to_stage of this BaseStationResponse.  # noqa: E501


        :return: The push_to_stage of this BaseStationResponse.  # noqa: E501
        :rtype: bool
        """
        return self._push_to_stage

    @push_to_stage.setter
    def push_to_stage(self, push_to_stage):
        """Sets the push_to_stage of this BaseStationResponse.


        :param push_to_stage: The push_to_stage of this BaseStationResponse.  # noqa: E501
        :type: bool
        """
        if push_to_stage is None:
            raise ValueError("Invalid value for `push_to_stage`, must not be `None`")  # noqa: E501

        self._push_to_stage = push_to_stage

    @property
    def release_ring(self):
        """Gets the release_ring of this BaseStationResponse.  # noqa: E501


        :return: The release_ring of this BaseStationResponse.  # noqa: E501
        :rtype: ReleaseRingChild
        """
        return self._release_ring

    @release_ring.setter
    def release_ring(self, release_ring):
        """Sets the release_ring of this BaseStationResponse.


        :param release_ring: The release_ring of this BaseStationResponse.  # noqa: E501
        :type: ReleaseRingChild
        """

        self._release_ring = release_ring

    @property
    def targeted_software_release(self):
        """Gets the targeted_software_release of this BaseStationResponse.  # noqa: E501


        :return: The targeted_software_release of this BaseStationResponse.  # noqa: E501
        :rtype: TargetedSoftwareReleaseChild
        """
        return self._targeted_software_release

    @targeted_software_release.setter
    def targeted_software_release(self, targeted_software_release):
        """Sets the targeted_software_release of this BaseStationResponse.


        :param targeted_software_release: The targeted_software_release of this BaseStationResponse.  # noqa: E501
        :type: TargetedSoftwareReleaseChild
        """

        self._targeted_software_release = targeted_software_release

    @property
    def current_software_release(self):
        """Gets the current_software_release of this BaseStationResponse.  # noqa: E501


        :return: The current_software_release of this BaseStationResponse.  # noqa: E501
        :rtype: CurrentSoftwareReleaseChild
        """
        return self._current_software_release

    @current_software_release.setter
    def current_software_release(self, current_software_release):
        """Sets the current_software_release of this BaseStationResponse.


        :param current_software_release: The current_software_release of this BaseStationResponse.  # noqa: E501
        :type: CurrentSoftwareReleaseChild
        """

        self._current_software_release = current_software_release

    @property
    def hardware_revision(self):
        """Gets the hardware_revision of this BaseStationResponse.  # noqa: E501


        :return: The hardware_revision of this BaseStationResponse.  # noqa: E501
        :rtype: HardwareRevisionChild
        """
        return self._hardware_revision

    @hardware_revision.setter
    def hardware_revision(self, hardware_revision):
        """Sets the hardware_revision of this BaseStationResponse.


        :param hardware_revision: The hardware_revision of this BaseStationResponse.  # noqa: E501
        :type: HardwareRevisionChild
        """

        self._hardware_revision = hardware_revision

    @property
    def receiver(self):
        """Gets the receiver of this BaseStationResponse.  # noqa: E501


        :return: The receiver of this BaseStationResponse.  # noqa: E501
        :rtype: BaseStationReceiverChild
        """
        return self._receiver

    @receiver.setter
    def receiver(self, receiver):
        """Sets the receiver of this BaseStationResponse.


        :param receiver: The receiver of this BaseStationResponse.  # noqa: E501
        :type: BaseStationReceiverChild
        """

        self._receiver = receiver

    @property
    def repeaters(self):
        """Gets the repeaters of this BaseStationResponse.  # noqa: E501

        A repeater extends a signal to allow communication between nodes   and Base Stations within large work sites.   A Base Station can connect with up to 4 repeaters.  # noqa: E501

        :return: The repeaters of this BaseStationResponse.  # noqa: E501
        :rtype: list[RepeaterChild]
        """
        return self._repeaters

    @repeaters.setter
    def repeaters(self, repeaters):
        """Sets the repeaters of this BaseStationResponse.

        A repeater extends a signal to allow communication between nodes   and Base Stations within large work sites.   A Base Station can connect with up to 4 repeaters.  # noqa: E501

        :param repeaters: The repeaters of this BaseStationResponse.  # noqa: E501
        :type: list[RepeaterChild]
        """
        if repeaters is None:
            raise ValueError("Invalid value for `repeaters`, must not be `None`")  # noqa: E501

        self._repeaters = repeaters

    @property
    def total_online_node_count(self):
        """Gets the total_online_node_count of this BaseStationResponse.  # noqa: E501

        The number of nodes talking to the Base Station.  This number includes the nodes talking to any receivers or repeaters connected to the Base Station.  # noqa: E501

        :return: The total_online_node_count of this BaseStationResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_online_node_count

    @total_online_node_count.setter
    def total_online_node_count(self, total_online_node_count):
        """Sets the total_online_node_count of this BaseStationResponse.

        The number of nodes talking to the Base Station.  This number includes the nodes talking to any receivers or repeaters connected to the Base Station.  # noqa: E501

        :param total_online_node_count: The total_online_node_count of this BaseStationResponse.  # noqa: E501
        :type: int
        """
        if total_online_node_count is None:
            raise ValueError("Invalid value for `total_online_node_count`, must not be `None`")  # noqa: E501

        self._total_online_node_count = total_online_node_count

    @property
    def allowed_auto_frequencies(self):
        """Gets the allowed_auto_frequencies of this BaseStationResponse.  # noqa: E501


        :return: The allowed_auto_frequencies of this BaseStationResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._allowed_auto_frequencies

    @allowed_auto_frequencies.setter
    def allowed_auto_frequencies(self, allowed_auto_frequencies):
        """Sets the allowed_auto_frequencies of this BaseStationResponse.


        :param allowed_auto_frequencies: The allowed_auto_frequencies of this BaseStationResponse.  # noqa: E501
        :type: list[str]
        """
        if allowed_auto_frequencies is None:
            raise ValueError("Invalid value for `allowed_auto_frequencies`, must not be `None`")  # noqa: E501

        self._allowed_auto_frequencies = allowed_auto_frequencies

    @property
    def last_data_update(self):
        """Gets the last_data_update of this BaseStationResponse.  # noqa: E501


        :return: The last_data_update of this BaseStationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._last_data_update

    @last_data_update.setter
    def last_data_update(self, last_data_update):
        """Sets the last_data_update of this BaseStationResponse.


        :param last_data_update: The last_data_update of this BaseStationResponse.  # noqa: E501
        :type: datetime
        """

        self._last_data_update = last_data_update

    @property
    def is_online(self):
        """Gets the is_online of this BaseStationResponse.  # noqa: E501

        Determines whether or not the Base Station is connected to a network (wifi, ethernet, cell tower etc)  # noqa: E501

        :return: The is_online of this BaseStationResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_online

    @is_online.setter
    def is_online(self, is_online):
        """Sets the is_online of this BaseStationResponse.

        Determines whether or not the Base Station is connected to a network (wifi, ethernet, cell tower etc)  # noqa: E501

        :param is_online: The is_online of this BaseStationResponse.  # noqa: E501
        :type: bool
        """

        self._is_online = is_online

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BaseStationResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BaseStationResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class JobResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'enqueued_time': 'datetime',
        'finished_time': 'datetime',
        'errored_time': 'datetime',
        'status': 'JobStatus',
        'type': 'JobType',
        'uploaded_file_name': 'str',
        'error_file_name': 'str',
        'location': 'LocationChild',
        'corporation': 'CorporationChild',
        'user': 'UserChild'
    }

    attribute_map = {
        'id': 'Id',
        'enqueued_time': 'EnqueuedTime',
        'finished_time': 'FinishedTime',
        'errored_time': 'ErroredTime',
        'status': 'Status',
        'type': 'Type',
        'uploaded_file_name': 'UploadedFileName',
        'error_file_name': 'ErrorFileName',
        'location': 'Location',
        'corporation': 'Corporation',
        'user': 'User'
    }

    def __init__(self, id=None, enqueued_time=None, finished_time=None, errored_time=None, status=None, type=None, uploaded_file_name=None, error_file_name=None, location=None, corporation=None, user=None):  # noqa: E501
        """JobResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._enqueued_time = None
        self._finished_time = None
        self._errored_time = None
        self._status = None
        self._type = None
        self._uploaded_file_name = None
        self._error_file_name = None
        self._location = None
        self._corporation = None
        self._user = None
        self.discriminator = None
        self.id = id
        self.enqueued_time = enqueued_time
        if finished_time is not None:
            self.finished_time = finished_time
        if errored_time is not None:
            self.errored_time = errored_time
        self.status = status
        self.type = type
        self.uploaded_file_name = uploaded_file_name
        if error_file_name is not None:
            self.error_file_name = error_file_name
        self.location = location
        self.corporation = corporation
        self.user = user

    @property
    def id(self):
        """Gets the id of this JobResponse.  # noqa: E501

        The unique Id for the Job  # noqa: E501

        :return: The id of this JobResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this JobResponse.

        The unique Id for the Job  # noqa: E501

        :param id: The id of this JobResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def enqueued_time(self):
        """Gets the enqueued_time of this JobResponse.  # noqa: E501

        The time the job was created  # noqa: E501

        :return: The enqueued_time of this JobResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._enqueued_time

    @enqueued_time.setter
    def enqueued_time(self, enqueued_time):
        """Sets the enqueued_time of this JobResponse.

        The time the job was created  # noqa: E501

        :param enqueued_time: The enqueued_time of this JobResponse.  # noqa: E501
        :type: datetime
        """
        if enqueued_time is None:
            raise ValueError("Invalid value for `enqueued_time`, must not be `None`")  # noqa: E501

        self._enqueued_time = enqueued_time

    @property
    def finished_time(self):
        """Gets the finished_time of this JobResponse.  # noqa: E501

        The time the job was finished  # noqa: E501

        :return: The finished_time of this JobResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._finished_time

    @finished_time.setter
    def finished_time(self, finished_time):
        """Sets the finished_time of this JobResponse.

        The time the job was finished  # noqa: E501

        :param finished_time: The finished_time of this JobResponse.  # noqa: E501
        :type: datetime
        """

        self._finished_time = finished_time

    @property
    def errored_time(self):
        """Gets the errored_time of this JobResponse.  # noqa: E501

        The time the job errored  # noqa: E501

        :return: The errored_time of this JobResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._errored_time

    @errored_time.setter
    def errored_time(self, errored_time):
        """Sets the errored_time of this JobResponse.

        The time the job errored  # noqa: E501

        :param errored_time: The errored_time of this JobResponse.  # noqa: E501
        :type: datetime
        """

        self._errored_time = errored_time

    @property
    def status(self):
        """Gets the status of this JobResponse.  # noqa: E501


        :return: The status of this JobResponse.  # noqa: E501
        :rtype: JobStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this JobResponse.


        :param status: The status of this JobResponse.  # noqa: E501
        :type: JobStatus
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def type(self):
        """Gets the type of this JobResponse.  # noqa: E501


        :return: The type of this JobResponse.  # noqa: E501
        :rtype: JobType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this JobResponse.


        :param type: The type of this JobResponse.  # noqa: E501
        :type: JobType
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def uploaded_file_name(self):
        """Gets the uploaded_file_name of this JobResponse.  # noqa: E501

        The name of the file that was uploaded  # noqa: E501

        :return: The uploaded_file_name of this JobResponse.  # noqa: E501
        :rtype: str
        """
        return self._uploaded_file_name

    @uploaded_file_name.setter
    def uploaded_file_name(self, uploaded_file_name):
        """Sets the uploaded_file_name of this JobResponse.

        The name of the file that was uploaded  # noqa: E501

        :param uploaded_file_name: The uploaded_file_name of this JobResponse.  # noqa: E501
        :type: str
        """
        if uploaded_file_name is None:
            raise ValueError("Invalid value for `uploaded_file_name`, must not be `None`")  # noqa: E501

        self._uploaded_file_name = uploaded_file_name

    @property
    def error_file_name(self):
        """Gets the error_file_name of this JobResponse.  # noqa: E501

        The name of the error file, if the job has a Status of FinishedWithErrors  # noqa: E501

        :return: The error_file_name of this JobResponse.  # noqa: E501
        :rtype: str
        """
        return self._error_file_name

    @error_file_name.setter
    def error_file_name(self, error_file_name):
        """Sets the error_file_name of this JobResponse.

        The name of the error file, if the job has a Status of FinishedWithErrors  # noqa: E501

        :param error_file_name: The error_file_name of this JobResponse.  # noqa: E501
        :type: str
        """

        self._error_file_name = error_file_name

    @property
    def location(self):
        """Gets the location of this JobResponse.  # noqa: E501


        :return: The location of this JobResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this JobResponse.


        :param location: The location of this JobResponse.  # noqa: E501
        :type: LocationChild
        """
        if location is None:
            raise ValueError("Invalid value for `location`, must not be `None`")  # noqa: E501

        self._location = location

    @property
    def corporation(self):
        """Gets the corporation of this JobResponse.  # noqa: E501


        :return: The corporation of this JobResponse.  # noqa: E501
        :rtype: CorporationChild
        """
        return self._corporation

    @corporation.setter
    def corporation(self, corporation):
        """Sets the corporation of this JobResponse.


        :param corporation: The corporation of this JobResponse.  # noqa: E501
        :type: CorporationChild
        """
        if corporation is None:
            raise ValueError("Invalid value for `corporation`, must not be `None`")  # noqa: E501

        self._corporation = corporation

    @property
    def user(self):
        """Gets the user of this JobResponse.  # noqa: E501


        :return: The user of this JobResponse.  # noqa: E501
        :rtype: UserChild
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this JobResponse.


        :param user: The user of this JobResponse.  # noqa: E501
        :type: UserChild
        """
        if user is None:
            raise ValueError("Invalid value for `user`, must not be `None`")  # noqa: E501

        self._user = user

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.hardware_status_api import HardwareStatusApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestHardwareStatusApi(unittest.TestCase):
    """HardwareStatusApi unit test stubs"""

    def setUp(self):
        self.api = HardwareStatusApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_collectors_status(self):
        """Test case for get_collectors_status

        Gets the online status for the desired base stations.  # noqa: E501
        """
        pass

    def test_get_hubs_status(self):
        """Test case for get_hubs_status

        Gets all status for hubs.  # noqa: E501
        """
        pass

    def test_get_nodes_status(self):
        """Test case for get_nodes_status

        Gets all status for nodes.  # noqa: E501
        """
        pass

    def test_get_repeaters_status(self):
        """Test case for get_repeaters_status

        Gets the online status for repeaters, grouped by location.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
